add_empty: Add Empty Cell

Description Usage Arguments Value

Description

Helper function to add an empty cell in a list

Usage

1
add_empty(list, item, index)

Arguments

list

List to be used.

item

String to be added as name of item in list.

index

Integer. Index of item to be added.

Value

List. New list with item added with '-' as value.


Aquarela-Advanced-Analytics/r2vortx documentation built on May 20, 2019, 8:46 a.m.