Description Usage Arguments Value
Helper function to add an empty cell in a list
1 |
list |
List to be used. |
item |
String to be added as name of item in list. |
index |
Integer. Index of item to be added. |
List. New list with item added with '-' as value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.